@@ -1,10 +1,8 @@
 '''
-This file is a part of Test Mile Arjuna
-Copyright 2018 Test Mile Software Testing Pvt Ltd
+This file is a part of Arjuna
+Copyright 2015-2020 Rahul Verma
 
-Website: www.TestMile.com
-Email: support [at] testmile.com
-Creator: Rahul Verma
+Website: www.RahulVerma.net
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -19,6 +17,8 @@ See the License for the specific language governing permissions and
 limitations under the License.
 '''
 
+from arjuna.interact.gui.auto.finder.emd import GuiElementMetaData
+
 class ArjunaException(Exception):
     def __init__(self, message, scrreenshots_path=None, child=None):
         # child is child exception
@@ -123,10 +123,27 @@ class WaitableError(BaseException):
     def __init__(self, message):
         super().__init__(message)
 
-class GuiElementNotFoundError(WaitableError):
+class _ElementNotFoundError(WaitableError):
 
-    def __init__(self, message, locator):
-        super().__init__("GuiElement(s) not found using locator: {}. Tool message: {}".format(locator, message))
+    def __init__(self, elem_name, *locators, message=None):
+        message = message and  "Error message: {}".format(message) or ""
+        super().__init__("{} not found using any of the locators: {}.{}".format(elem_name, GuiElementMetaData.locators_as_str(locators), message))
+
+class _ElementPresentError(WaitableError):
+
+    def __init__(self, elem_type, *locators, message=None):
+        message = message and  "Error message: {}".format(message) or ""
+        super().__init__("{} expected to be absent but still present for one of the locators: {}.{}".format(elem_type, GuiElementMetaData.locators_as_str(locators), message))
+
+class GuiElementNotFoundError(_ElementNotFoundError):
+
+    def __init__(self, *locators, message=None):
+        super().__init__("GuiElement(s)", *locators, message=message)
+
+class GuiElementPresentError(_ElementPresentError):
+
+    def __init__(self, *locators, message=None):
+        super().__init__("GuiElement(s)", *locators, message=message)
 
 class GuiElementNotReadyError(WaitableError):
 
@@ -137,3 +154,22 @@ class GuiElementTextNotSetError(WaitableError):
 
     def __init__(self, message):
         super().__init__(". Tool message: {}".format(message))
+
+class ChildWindowNotFoundError(_ElementNotFoundError):
+
+    def __init__(self, *locators):
+        super().__init__("Child window", *locators)
+
+class ChildFrameNotFoundError(_ElementNotFoundError):
+
+    def __init__(self, *locators):
+        super().__init__("Frame", *locators)
+
+class TimeoutError(WaitableError):
+
+    def __init__(self, context, message):
+        super().__init__(". Timeout in {}. Error Message: {}".format(context, message))  
+
+class DataSourceFinished(StopIteration):
+    def __init__(self, msg=None):
+        super().__init__(msg is None and "Done" or msg)
\ No newline at end of file
