@@ -1,3 +1,23 @@
+'''
+This file is a part of Arjuna
+Copyright 2015-2020 Rahul Verma
+
+Website: www.RahulVerma.net
+
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+
+  http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
+'''
+
+
 import abc
 import os
 from enum import Enum
@@ -53,9 +73,9 @@ class Gui(AsserterMixIn):
         return self.__class__.__qualname__
 
 
-class AppPortion(Gui):
+class AppContent(Gui):
 
-    def __init__(self, *, automator, label=None):
+    def __init__(self, *args, automator, label=None, **kwargs):
         super().__init__(config=automator.config, ext_config=automator.ext_config, label=label)
         self.__app = automator.app
         self.__automator = automator
@@ -79,7 +99,7 @@ class AppPortion(Gui):
     def gui_def(self):
         return self.__guidef
 
-    def externalize_guidef(self, ns_dir=None, def_file_name=None):
+    def externalize_def(self, ns_dir=None, def_file_name=None):
         self.__def_file_name = def_file_name is not None and def_file_name or "{}.gns".format(self.label)        
         from arjuna.core.enums import ArjunaOption
         ns_dir = ns_dir and ns_dir or self.app.ns_dir
@@ -97,6 +117,10 @@ class AppPortion(Gui):
     def def_file_path(self):
         return self.__def_file_path
 
+    def prepare(self):
+        # Children can override and write any necessary preparation instructions e.g. externalizing
+        pass
+
     def reach_until(self):
         # Children can override and write any necessary loading instructions
         pass
@@ -104,7 +128,8 @@ class AppPortion(Gui):
     def validate_readiness(self):
         pass
 
-    def __load(self):
+    def _load(self, *args, **kwargs):
+        self.prepare(*args, **kwargs)
         try:
             self.validate_readiness()
         except:
@@ -112,12 +137,7 @@ class AppPortion(Gui):
                 self.reach_until()
                 self.validate_readiness()
             except Exception as e:
-                raise Exception(
-                    "UI [{}] with SetuId [{}] did not load as expected. Error: {}.",
-                    self.__class__.__name__,
-                    self.get_setu_id(),
-                    str(e)
-                )
+                raise Exception("GUI [{}] did not load as expected. Error: {}.".format(self.qual_name, str(e)))
 
     def transit(self, page):
         pass
@@ -137,6 +157,8 @@ class AppPortion(Gui):
                 raise Exception("A With object or name of element is expected as argument.")
 
             if w.wtype == WithType.GNS_NAME:
+                if isinstance(w.wvalue, Enum):
+                    w.wvalue = w.wvalue.name
                 out.extend(self.gui_def.convert_to_with(w))
             else:
                 out.append(w)
@@ -147,28 +169,43 @@ class AppPortion(Gui):
     def browser(self):
         return self.impl_gui.browser
 
-    def element(self, *str_or_with_locators):
-        return self.automator.element(self.convert_to_with_lmd(*str_or_with_locators))
+    def element(self, *str_or_with_locators, iconfig=None):
+        return self.automator.element(self, self.convert_to_with_lmd(*str_or_with_locators), iconfig=iconfig)
 
-    def multi_element(self, *str_or_with_locators):
-        return self.automator.multi_element(self.convert_to_with_lmd(*str_or_with_locators))
+    def multi_element(self, *str_or_with_locators, iconfig=None):
+        return self.automator.multi_element(self, self.convert_to_with_lmd(*str_or_with_locators), iconfig=iconfig)
 
-    def dropdown(self, *str_or_with_locators):
-        return self.automator.dropdown(self.convert_to_with_lmd(*str_or_with_locators))
+    def dropdown(self, *str_or_with_locators, option_container_locator=None, option_locator=None, iconfig=None):
+        return self.automator.dropdown(
+            self, 
+            self.convert_to_with_lmd(*str_or_with_locators),
+            option_container_lmd=option_container_locator and self.convert_to_with_lmd(option_container_locator) or None,
+            option_lmd=option_locator and self.convert_to_with_lmd(option_locator) or None,
+            iconfig=iconfig
+        )
 
-    def radio_group(self, *str_or_with_locators):
-        return self.automator.radio_group(self.convert_to_with_lmd(*str_or_with_locators))
+    def radio_group(self, *str_or_with_locators, iconfig=None):
+        return self.automator.radio_group(self, self.convert_to_with_lmd(*str_or_with_locators), iconfig=iconfig)
 
-    def tab_group(self, *str_or_with_locators, tab_header_locator, content_relation_attr, content_relation_type):
+    def tab_group(self, *str_or_with_locators, tab_header_locator, content_relation_attr, content_relation_type, iconfig=None):
         return self.automator.tab_group(
+            self,
             self.convert_to_with_lmd(*str_or_with_locators),
             tab_header_lmd=self.convert_to_with_lmd(tab_header_locator),
             content_relation_attr=content_relation_attr, 
-            content_relation_type=content_relation_type
+            content_relation_type=content_relation_type, 
+            iconfig=iconfig
         )
 
-    def frame(self, *str_or_with_locators):
-        return self.automator.frame(self.convert_to_with_lmd(*str_or_with_locators))
+    def wait_until_element_absent(self, *str_or_with_locators):
+        return self.automator.wait_until_element_absent(self.convert_to_with_lmd(*str_or_with_locators))
+
+    @property
+    def dom_root(self):
+        return self.automator.dom_root(self)
+
+    def frame(self, *str_or_with_locators, iconfig=None):
+        return self.automator.frame(self, self.convert_to_with_lmd(*str_or_with_locators), iconfig=iconfig)
 
     @property
     def alert(self):
@@ -181,6 +218,13 @@ class AppPortion(Gui):
     def child_window(self, *str_or_with_locators):
         return self.automator.child_window(self.convert_to_with_lmd(*str_or_with_locators))
 
+    @property
+    def latest_child_window(self):
+        return self.automator.latest_child_window
+
+    def close_all_child_windows(self):
+        self.automator.close_all_child_windows()
+
     @property
     def browser(self):
         return self.automator.browser
@@ -188,5 +232,10 @@ class AppPortion(Gui):
     def set_slomo(self, on, interval=None):
         self.automator.set_slomo(on, interval)
 
-    def execute_javascript(self, js):
-        return self.automator.execute_javascript(js)
\ No newline at end of file
+    def execute_javascript(self, js, *args):
+        return self.automator.execute_javascript(js, *args)
+
+    def take_screenshot(self, name=None):
+        return self.automator.take_screenshot(name)
+
+
